pub struct MediaTrackStoppedPayload {
pub track_id: u64,
pub kind: String,
pub session_id: u64,
}Expand description
Fired when a track is stopped, either programmatically or by the user dismissing a screen share via the browser’s native share picker.
session_id is 0 for tracks not associated with an active session.
Fields
track_id: u64kind: Stringsession_id: u64Trait Implementations
Sourceimpl Debug for MediaTrackStoppedPayload
impl Debug for MediaTrackStoppedPayload